@@ -130,9 +130,9 @@ class Editor(Library):
         status = self.library.GW2RunSession(ct_session)
 
         if status not in successes.success_codes:
-            log.error(f"\n\tsession: {session}\n\tstatus: {status}")
+            log.error(f"\n\tsession: {session}\n\tstatus: {status}\n\tGW2FileErrorMsg: {self.GW2FileErrorMsg(session)}")
         else:
-            log.debug(f"\n\tsession: {session}\n\tstatus: {status}")
+            log.debug(f"\n\tsession: {session}\n\tstatus: {status}\n\tGW2FileErrorMsg: {self.GW2FileErrorMsg(session)}")
 
         return status
 
@@ -1102,3 +1102,51 @@ class Editor(Library):
             import_files_dict[relative_path] = import_bytes
 
         return import_files_dict
+
+    def GW2FileErrorMsg(self, session: int):
+        """ Retrieve the Glasswall Session Process error message.
+
+        Args:
+            session (int): The session number.
+
+        Returns:
+            error_message (str): The Glasswall Session Process error message.
+        """
+        # Validate arg types
+        if not isinstance(session, int):
+            raise TypeError(session)
+
+        # API function declaration
+        self.library.GW2FileErrorMsg.argtypes = [
+            ct.c_size_t,
+            ct.POINTER(ct.c_void_p),
+            ct.POINTER(ct.c_size_t)
+        ]
+
+        # Variable initialisation
+        ct_session = ct.c_size_t(session)
+        ct_buffer = ct.c_void_p()
+        ct_buffer_length = ct.c_size_t(0)
+
+        # API call
+        status = self.library.GW2FileErrorMsg(
+            ct_session,
+            ct.byref(ct_buffer),
+            ct.byref(ct_buffer_length)
+        )
+
+        if status not in successes.success_codes:
+            log.error(f"\n\tsession: {session}\n\tstatus: {status}")
+            raise errors.error_codes.get(status, errors.UnknownErrorCode)(status)
+        else:
+            log.debug(f"\n\tsession: {session}\n\tstatus: {status}")
+
+        # Editor wrote to a buffer, convert it to bytes
+        error_bytes = utils.buffer_to_bytes(
+            ct_buffer,
+            ct_buffer_length
+        )
+
+        error_message = error_bytes.decode()
+
+        return error_message
